rpms/apt/F-8 apt-0.5.15lorg3.93-multilib-obsoletes-hack.patch, NONE, 1.1 apt-0.5.15lorg3.93-repomd-assert.patch, NONE, 1.1 apt.spec, 1.45, 1.46 rpmpriorities, 1.5, 1.6

Panu Matilainen (pmatilai) fedora-extras-commits at redhat.com
Mon Nov 19 07:25:01 UTC 2007


Author: pmatilai

Update of /cvs/pkgs/rpms/apt/F-8
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv26280

Modified Files:
	apt.spec rpmpriorities 
Added Files:
	apt-0.5.15lorg3.93-multilib-obsoletes-hack.patch 
	apt-0.5.15lorg3.93-repomd-assert.patch 
Log Message:
- Sync with rawhide to fix #389361 and #353271


apt-0.5.15lorg3.93-multilib-obsoletes-hack.patch:

--- NEW FILE apt-0.5.15lorg3.93-multilib-obsoletes-hack.patch ---
diff --git a/apt-pkg/policy.cc b/apt-pkg/policy.cc
index 70b392a..3d4574f 100644
--- a/apt-pkg/policy.cc
+++ b/apt-pkg/policy.cc
@@ -295,6 +295,13 @@ signed short pkgPolicy::GetPkgPriority(const pkgCache::PkgIterator &Pkg)
 	    Max = Prio;
       }      
    }
+
+   /* XXX HACK alert: give non-native packages slightly lower priority */
+   string CAS = _config->Find("RPM::CompatArchSuffix");
+   if (!CAS.empty() && 
+	string(Pkg.Name()).rfind(CAS) != string::npos) {
+        Max--;
+   }
    return Max;
 }
 									/*}}}*/
diff --git a/apt-pkg/rpm/rpmpackagedata.cc b/apt-pkg/rpm/rpmpackagedata.cc
index 7dbac3a..24060e2 100644
--- a/apt-pkg/rpm/rpmpackagedata.cc
+++ b/apt-pkg/rpm/rpmpackagedata.cc
@@ -42,6 +42,10 @@ RPMPackageData::RPMPackageData()
       PreferredArch = _config->Find(PA.c_str(), BaseArch.c_str());
       string CAS = MLBase + "::CompatArchSuffix";
       CompatArchSuffix = _config->Find(CAS.c_str(), ".32bit");
+
+      // Blech, export for easy use elsewhere .. for now 
+      _config->Set("RPM::PreferredArch", PreferredArch);
+      _config->Set("RPM::CompatArchSuffix", CompatArchSuffix);
    }
 
    // Populate priorities

apt-0.5.15lorg3.93-repomd-assert.patch:

--- NEW FILE apt-0.5.15lorg3.93-repomd-assert.patch ---
commit 40dc6292aaa1ffa9c06fd94b276f378411b3b629
Author: Panu Matilainen <pmatilai at laiskiainen.org>
Date:   Mon Nov 19 09:09:39 2007 +0200

    Fix assert failure in some cases where repomd.xml can't be found

diff --git a/apt-pkg/rpm/rpmindexfile.cc b/apt-pkg/rpm/rpmindexfile.cc
index 937712a..1e1eb22 100644
--- a/apt-pkg/rpm/rpmindexfile.cc
+++ b/apt-pkg/rpm/rpmindexfile.cc
@@ -561,7 +561,12 @@ string rpmRepomdIndex::ArchiveInfo(pkgCache::VerIterator Ver) const
 }
 pkgCache::PkgFileIterator rpmRepomdIndex::FindInCache(pkgCache &Cache) const
 {
-   string FileName = IndexPath();
+   string FileName = "";
+   /* repomd requires release to be present to find any other files */
+   if (FileExists(ReleasePath())) {
+      FileName = IndexPath();
+   }
+
    pkgCache::PkgFileIterator File = Cache.FileBegin();
    for (; File.end() == false; File++)
    {


Index: apt.spec
===================================================================
RCS file: /cvs/pkgs/rpms/apt/F-8/apt.spec,v
retrieving revision 1.45
retrieving revision 1.46
diff -u -r1.45 -r1.46
--- apt.spec	23 Aug 2007 09:41:52 -0000	1.45
+++ apt.spec	19 Nov 2007 07:24:22 -0000	1.46
@@ -6,7 +6,7 @@
 Summary: Debian's Advanced Packaging Tool with RPM support
 Name: apt
 Version: 0.5.15lorg3.93
-Release: 2%{?dist}
+Release: 4%{?dist}
 Group: System Environment/Base
 URL: http://apt-rpm.org/
 # SourceLicense: GPLv2+ except lua/ which is MIT
@@ -36,6 +36,10 @@
 Patch0: apt-0.5.15lorg3.2-ppc.patch
 # band aid for mmap issues (#211254)
 Patch1: apt-0.5.15lorg3.x-cache-corruption.patch
+# multilib obsoletes hackery (#353271)
+Patch2: apt-0.5.15lorg3.93-multilib-obsoletes-hack.patch
+# avoid assertion failure when repomd.xml doesn't exist
+Patch3: apt-0.5.15lorg3.93-repomd-assert.patch
 
 BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
 
@@ -48,7 +52,6 @@
 BuildRequires: bzip2-devel
 BuildRequires: libstdc++-devel
 BuildRequires: gettext
-BuildRequires: docbook-utils
 BuildRequires: perl
 BuildRequires: readline-devel
 BuildRequires: ncurses-devel
@@ -121,12 +124,8 @@
 %setup -q
 %patch0 -p1 -b .ppc
 %patch1 -p0 -b .mmap
-
-# fix docs to reference correct paths
-perl -pi -e \
- 's|\bconfigure-index\.gz\b|configure-index| ;
-  s|/usr/share/doc/apt/|%{_docdir}/%{name}-%{version}/|' \
- doc/apt.ent doc/*/apt.ent.* doc/offline.sgml contrib/apt-wrapper/apt.ent
+%patch2 -p1 -b .obsoletes-hack
+%patch3 -p1 -b .repomd-assert
 
 install -pm 644 %{SOURCE19} comps2prio.xsl
 
@@ -136,7 +135,6 @@
 %build
 %configure --disable-dependency-tracking --disable-static
 
-SGML_CATALOG_FILES=$(ls -1 %{_sysconfdir}/sgml/sgml-docbook-3.1* | head -n 1) \
 make %{?_smp_mflags}
 
 make -C python %{?_smp_mflags} PYTHON="%{__python}"
@@ -293,6 +291,14 @@
 
 
 %changelog
+* Mon Nov 19 2007 Panu Matilainen <pmatilai at redhat.com> 0.5.15lorg3.93-4
+- Fix assert failure when repomd.xml isn't available locally (#389361)
+
+* Fri Nov 16 2007 Panu Matilainen <pmatilai at redhat.com> 0.5.15lorg3.93-3
+- Hackery to help (multilib) obsoletes (#353271)
+- Drop termcap + libtermcap from rpmpriorities to avoid installing needlessly
+- Drop docbook-utils dependency and hackery, no longer needed
+
 * Thu Aug 23 2007 Panu Matilainen <pmatilai at redhat.com> 0.5.15lorg3.93-2
 - gah, need to buildrequire gawk now...
 


Index: rpmpriorities
===================================================================
RCS file: /cvs/pkgs/rpms/apt/F-8/rpmpriorities,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- rpmpriorities	2 Aug 2007 12:12:07 -0000	1.5
+++ rpmpriorities	19 Nov 2007 07:24:22 -0000	1.6
@@ -1,10 +1,8 @@
 Essential:
   grub
-  termcap
   ed
   kbd
   iproute
-  libtermcap
   libgcc
   setserial
   file




More information about the fedora-extras-commits mailing list
diff --git a/apt-pkg/algorithms.cc b/apt-pkg/algorithms.cc
index a3fb896..cd226ee 100644
--- a/apt-pkg/algorithms.cc
+++ b/apt-pkg/algorithms.cc
@@ -962,8 +962,9 @@ bool pkgProblemResolver::Resolve(bool BrokenFix)
 		    End->Type != pkgCache::Dep::Conflicts &&
 		    End->Type != pkgCache::Dep::Obsoletes))
 	       {
-		  // Try a little harder to fix protected packages..
-		  if ((Flags[I->ID] & Protected) == Protected)
+		  // Try a little harder for protected packages and obsoletes..
+		  if ((Flags[I->ID] & Protected) == Protected ||
+		      End->Type == pkgCache::Dep::Obsoletes)
 		  {
 		     if (DoUpgrade(Pkg) == true)
 		     {